==> docs_sdk_archive_luna-sdk_alma_rel_v.5.31.2.zip: docs_sdk_archive_luna-sdk_alma_rel_v.5.31.2/luna-sdk_alma_rel_v.5.31.2/doc/fsdk/html/search/enumvalues_8.js <==
var searchData=
[
  ['ic_5fbest_5fcompression',['IC_BEST_COMPRESSION',['../structfsdk_1_1_image.html#acb272c751b60925b57a543cf19f31a5daccd72f086a3257b06c12b790a683f2d6',1,'fsdk::Image']]],
  ['ic_5fhard_5fcompression',['IC_HARD_COMPRESSION',['../structfsdk_1_1_image.html#acb272c751b60925b57a543cf19f31a5da60cdeb7647e393444a05d358810293f5',1,'fsdk::Image']]],
  ['ic_5fmedium_5fcompression',['IC_MEDIUM_COMPRESSION',['../structfsdk_1_1_image.html#acb272c751b60925b57a543cf19f31a5daf526f9c09cd1a065f528dc6518895615',1,'fsdk::Image']]],
  ['ic_5fno_5fcompression',['IC_NO_COMPRESSION',['../structfsdk_1_1_image.html#acb272c751b60925b57a543cf19f31a5dab75738e569f17ad386d0ff4cb90eabb9',1,'fsdk::Image']]],
  ['ic_5fsmall_5fcompression',['IC_SMALL_COMPRESSION',['../structfsdk_1_1_image.html#acb272c751b60925b57a543cf19f31a5dae811dec1e75f575972a667e83a23bd34',1,'fsdk::Image']]],
  ['incompatible',['Incompatible',['../structfsdk_1_1_i_descriptor_batch.html#af8054a7215c500c856b6b10e41e4be93a2a208768bc7995cc26b7f3797d24b0b1',1,'fsdk::IDescriptorBatch']]],
  ['incompatibledescriptors',['IncompatibleDescriptors',['../namespacefsdk.html#a811cc08198c8cb908dc856217ef6c4f6a98530c9f4969e4a2e2d84a7776a2be2a',1,'fsdk']]],
  ['incompatiblemodelversions',['IncompatibleModelVersions',['../namespacefsdk.html#a811cc08198c8cb908dc856217ef6c4f6acd90a241053a97f8ff283746c8bed63f',1,'fsdk']]],
  ['infrared',['Infrared',['../structfsdk_1_1_image_color_estimation.html#a571307a256f649446ab9f437604fd48cade1c318db60bc972858577273c2d1ddd',1,'fsdk::ImageColorEstimation']]],
  ['inputarchive',['InputArchive',['../structfsdk_1_1_i_serializable_object.html#a2e8ee7bbbbc97731f3dddfcf9c5276f0af7d6ea2b343a99ac0a2cd306ed96b5c7',1,'fsdk::ISerializableObject']]],
  ['int1',['Int1',['../structfsdk_1_1_i_settings_provider_1_1_value.html#a593ad9694be5ec4dfe8982cef26fe947a95a8d18f7debfc437b1669849e7dd925',1,'fsdk::ISettingsProvider::Value']]],
  ['int2',['Int2',['../structfsdk_1_1_i_settings_provider_1_1_value.html#a593ad9694be5ec4dfe8982cef26fe947adf23e4f8136317e83ee4579ba2a5e066',1,'fsdk::ISettingsProvider::Value']]],
  ['int3',['Int3',['../structfsdk_1_1_i_settings_provider_1_1_value.html#a593ad9694be5ec4dfe8982cef26fe947ab6b18a107e12ec3a414343d93b4d69ec',1,'fsdk::ISettingsProvider::Value']]],
  ['int4',['Int4',['../structfsdk_1_1_i_settings_provider_1_1_value.html#a593ad9694be5ec4dfe8982cef26fe947ac4b020c2b070595a491d27e82c03ab5d',1,'fsdk::ISettingsProvider::Value']]],
  ['internal',['Internal',['../structfsdk_1_1_i_descriptor_batch.html#af8054a7215c500c856b6b10e41e4be93aafbf0897a5a83fdd873dfb032ec695d3',1,'fsdk::IDescriptorBatch::Internal()'],['../structfsdk_1_1_i_settings_provider.html#a645a0b8fb7db4e4d2ddc5bdb68a5cad5aafbf0897a5a83fdd873dfb032ec695d3',1,'fsdk::ISettingsProvider::Internal()'],['../namespacefsdk.html#a811cc08198c8cb908dc856217ef6c4f6aafbf0897a5a83fdd873dfb032ec695d3',1,'fsdk::Internal()'],['../namespacefsdk.html#ab7f8be96a87fd4e85bd762a7f8f8f8fbaafbf0897a5a83fdd873dfb032ec695d3',1,'fsdk::Internal()'],['../namespacefsdk.html#a4d0fbacdb0e56a6f79c2eb3e276c4e83aafbf0897a5a83fdd873dfb032ec695d3',1,'fsdk::Internal()']]],
  ['invalidarchive',['InvalidArchive',['../structfsdk_1_1_image.html#a7929a4eb6155bd9430dac56142672936a538273d971a3da3f944bfb95091df5d8',1,'fsdk::Image']]],
  ['invalidattribute',['InvalidAttribute',['../structfsdk_1_1_i_settings_provider.html#a645a0b8fb7db4e4d2ddc5bdb68a5cad5a49069827e26a70a158193ed0595b485b',1,'fsdk::ISettingsProvider']]],
  ['invalidbatch',['InvalidBatch',['../namespacefsdk.html#a811cc08198c8cb908dc856217ef6c4f6a16cd466ba03251484ec4e4b1dba364f5',1,'fsdk']]],
  ['invalidbitmap',['InvalidBitmap',['../structfsdk_1_1_image.html#a7929a4eb6155bd9430dac56142672936abcdbc5068527815bd978d3cbba5e7deb',1,'fsdk::Image']]],
  ['invalidbuffersize',['InvalidBufferSize',['../namespacefsdk.html#a811cc08198c8cb908dc856217ef6c4f6a32d8099d0ff5ab8d8893e6902eeb1ad0',1,'fsdk']]],
  ['invalidcdata',['InvalidCdata',['../structfsdk_1_1_i_settings_provider.html#a645a0b8fb7db4e4d2ddc5bdb68a5cad5a20c6429b7ff545070b48df0668d686fe',1,'fsdk::ISettingsProvider']]],
  ['invalidcomment',['InvalidComment',['../structfsdk_1_1_i_settings_provider.html#a645a0b8fb7db4e4d2ddc5bdb68a5cad5ac51b09d66c17f113d52d2822fb71a757',1,'fsdk::ISettingsProvider']]],
  ['invalidconfig',['InvalidConfig',['../namespacefsdk.html#a811cc08198c8cb908dc856217ef6c4f6a636bc5ca1e0ceb3e4c67067618d7ae09',1,'fsdk']]],
  ['invalidconversion',['InvalidConversion',['../structfsdk_1_1_image.html#a7929a4eb6155bd9430dac56142672936aaf9d45225e9d3edf59f2fd40d4b9f157',1,'fsdk::Image']]],
  ['invalidcudakernel',['InvalidCudaKernel',['../structfsdk_1_1_image.html#a7929a4eb6155bd9430dac56142672936afc9c6b34d28deffc4e146c11aae1c623',1,'fsdk::Image']]],
  ['invaliddataptr',['InvalidDataPtr',['../structfsdk_1_1_image.html#a7929a4eb6155bd9430dac56142672936a588c80ae8885b51a5f0700894da5affe',1,'fsdk::Image']]],
  ['invaliddatasize',['InvalidDataSize',['../structfsdk_1_1_image.html#a7929a4eb6155bd9430dac56142672936a0a86fcdcc2094e925e3166b9710f8d82',1,'fsdk::Image']]],
  ['invaliddescriptor',['InvalidDescriptor',['../namespacefsdk.html#a811cc08198c8cb908dc856217ef6c4f6a5b17c8e23099885736ba8f8d05c32f6c',1,'fsdk']]],
  ['invaliddescriptorbatch',['InvalidDescriptorBatch',['../namespacefsdk.html#a811cc08198c8cb908dc856217ef6c4f6a7b9735f9f1303453ad41cd38fc3b2b77',1,'fsdk']]],
  ['invaliddescriptorid',['InvalidDescriptorId',['../namespacefsdk.html#a811cc08198c8cb908dc856217ef6c4f6a1a86be0290d50e138737e4cc52665468',1,'fsdk']]],
  ['invaliddetection',['InvalidDetection',['../namespacefsdk.html#a811cc08198c8cb908dc856217ef6c4f6a8f36304eeb9e7bd7da166f71d3a5671f',1,'fsdk']]],
  ['invaliddevice',['InvalidDevice',['../structfsdk_1_1_image.html#a7929a4eb6155bd9430dac56142672936a3634e01cc1296daece9832c5396808c2',1,'fsdk::Image']]],
  ['invaliddoctype',['InvalidDocType',['../structfsdk_1_1_i_settings_provider.html#a645a0b8fb7db4e4d2ddc5bdb68a5cad5a93650de0861d0516977f25b86ee42e5a',1,'fsdk::ISettingsProvider']]],
  ['invalidendelement',['InvalidEndElement',['../structfsdk_1_1_i_settings_provider.html#a645a0b8fb7db4e4d2ddc5bdb68a5cad5a811a6b500aa2374e3a70057141dccbbf',1,'fsdk::ISettingsProvider']]],
  ['invalidformat',['InvalidFormat',['../structfsdk_1_1_image.html#a7929a4eb6155bd9430dac56142672936ade236a235b4e8ffc9141676624753b2d',1,'fsdk::Image']]],
  ['invalidheight',['InvalidHeight',['../structfsdk_1_1_image.html#a7929a4eb6155bd9430dac56142672936aaff424fc1ea568827830b838a80cd934',1,'fsdk::Image']]],
  ['invalidimage',['InvalidImage',['../structfsdk_1_1_image.html#a7929a4eb6155bd9430dac56142672936a107a93f5ad9b48f874341eaa0141e0f9',1,'fsdk::Image::InvalidImage()'],['../namespacefsdk.html#a811cc08198c8cb908dc856217ef6c4f6a107a93f5ad9b48f874341eaa0141e0f9',1,'fsdk::InvalidImage()']]],
  ['invalidimageformat',['InvalidImageFormat',['../namespacefsdk.html#a811cc08198c8cb908dc856217ef6c4f6a4bb4fd071cf54bae94ece53fa687b8bf',1,'fsdk']]],
  ['invalidimagesize',['InvalidImageSize',['../namespacefsdk.html#a811cc08198c8cb908dc856217ef6c4f6a5a606ed9e3b82871cb31eb26d467bebf',1,'fsdk']]],
  ['invalidinput',['InvalidInput',['../structfsdk_1_1_i_descriptor_batch.html#af8054a7215c500c856b6b10e41e4be93ad8f78ca9a692a9411afbc7584b69d043',1,'fsdk::IDescriptorBatch::InvalidInput()'],['../structfsdk_1_1_image.html#a7929a4eb6155bd9430dac56142672936ad8f78ca9a692a9411afbc7584b69d043',1,'fsdk::Image::InvalidInput()'],['../namespacefsdk.html#a811cc08198c8cb908dc856217ef6c4f6ad8f78ca9a692a9411afbc7584b69d043',1,'fsdk::InvalidInput()'],['../namespacefsdk.html#ab7f8be96a87fd4e85bd762a7f8f8f8fbad8f78ca9a692a9411afbc7584b69d043',1,'fsdk::InvalidInput()']]],
  ['invalidlandmarks5',['InvalidLandmarks5',['../namespacefsdk.html#a811cc08198c8cb908dc856217ef6c4f6ab5c07ccab2c5b9c7577b777263e692aa',1,'fsdk']]],
  ['invalidlandmarks68',['InvalidLandmarks68',['../namespacefsdk.html#a811cc08198c8cb908dc856217ef6c4f6a5e323dba014fd8072bb4a29f3e39db8d',1,'fsdk']]],
  ['invalidmemory',['InvalidMemory',['../structfsdk_1_1_image.html#a7929a4eb6155bd9430dac56142672936a83fe3c82514cc399b416bbb9d25ac9a9',1,'fsdk::Image']]],
  ['invalidpath',['InvalidPath',['../structfsdk_1_1_image.html#a7929a4eb6155bd9430dac56142672936a5d0744802b24f44a161d350c25d76c7b',1,'fsdk::Image::InvalidPath()'],['../namespacefsdk.html#a811cc08198c8cb908dc856217ef6c4f6a5d0744802b24f44a161d350c25d76c7b',1,'fsdk::InvalidPath()']]],
  ['invalidpcdata',['InvalidPcdata',['../structfsdk_1_1_i_settings_provider.html#a645a0b8fb7db4e4d2ddc5bdb68a5cad5a65d83fd76501c29718cc8fde8b8f33db',1,'fsdk::ISettingsProvider']]],
  ['invalidpi',['InvalidPi',['../structfsdk_1_1_i_settings_provider.html#a645a0b8fb7db4e4d2ddc5bdb68a5cad5a96fe5a2a900fba7e5dd6fe5519f09e90',1,'fsdk::ISettingsProvider']]],
  ['invalidrect',['InvalidRect',['../namespacefsdk.html#a811cc08198c8cb908dc856217ef6c4f6a48a3a3a046f78d13629f687cc97461a0',1,'fsdk']]],
  ['invalidresidence',['InvalidResidence',['../structfsdk_1_1_image.html#a7929a4eb6155bd9430dac56142672936a2a7695a194a2f785215c4ed058e2bf7b',1,'fsdk::Image']]],
  ['invalidserializedobject',['InvalidSerializedObject',['../namespacefsdk.html#a811cc08198c8cb908dc856217ef6c4f6af3c0d24a751f6da0fe4f81bb2e10bb19',1,'fsdk']]],
  ['invalidsettings',['InvalidSettings',['../structfsdk_1_1_i_settings_provider.html#a645a0b8fb7db4e4d2ddc5bdb68a5cad5a37a5f254c366f6c4dcba8bfd75f1070e',1,'fsdk::ISettingsProvider']]],
  ['invalidsettingsprovider',['InvalidSettingsProvider',['../namespacefsdk.html#a811cc08198c8cb908dc856217ef6c4f6ab1af2f31ddaa685b9fabe328f28f3a6f',1,'fsdk']]],
  ['invalidspansize',['InvalidSpanSize',['../namespacefsdk.html#a811cc08198c8cb908dc856217ef6c4f6a9a93b3012aa094825f11f65e07763bb3',1,'fsdk']]],
  ['invalidstartelement',['InvalidStartElement',['../structfsdk_1_1_i_settings_provider.html#a645a0b8fb7db4e4d2ddc5bdb68a5cad5a17b7fccdd65da9c5a54552c3685041a4',1,'fsdk::ISettingsProvider']]],
  ['invalidtag',['InvalidTag',['../structfsdk_1_1_i_settings_provider.html#a645a0b8fb7db4e4d2ddc5bdb68a5cad5af155a86534ba8c83bd9ced7c8f510b4c',1,'fsdk::ISettingsProvider']]],
  ['invalidtransformation',['InvalidTransformation',['../namespacefsdk.html#a811cc08198c8cb908dc856217ef6c4f6a21481cb38ecea41b765ab2d86b594053',1,'fsdk']]],
  ['invalidtype',['InvalidType',['../structfsdk_1_1_image.html#a7929a4eb6155bd9430dac56142672936ac85f85f7c13ed006eed130ec183aa810',1,'fsdk::Image']]],
  ['invalidwidth',['InvalidWidth',['../structfsdk_1_1_image.html#a7929a4eb6155bd9430dac56142672936a6518a24cb2d8166f5c57016e65e3f419',1,'fsdk::Image']]],
  ['ioerror',['IOError',['../structfsdk_1_1_i_settings_provider.html#a645a0b8fb7db4e4d2ddc5bdb68a5cad5a5206bd7472156351d2d9a99633ac9580',1,'fsdk::ISettingsProvider::IOError()'],['../structfsdk_1_1_i_descriptor_batch.html#af8054a7215c500c856b6b10e41e4be93af05cfcbf5123775f7c73e520a8d861e1',1,'fsdk::IDescriptorBatch::IoError()']]],
  ['ir_5fx8x8x8',['IR_X8X8X8',['../structfsdk_1_1_format.html#a9074e215a3c98d8e5b125bbec8d19af1af4ca5a5a1ea5b7005c89a9cd0911d0b4',1,'fsdk::Format']]],
  ['iso',['ISO',['../structfsdk_1_1_head_pose_estimation.html#aa2121a6759ada82ee49750f4922fd9a7a4db45576db7f96e820b1388d1c522aff',1,'fsdk::HeadPoseEstimation']]]
];

==> docs_sdk_archive_luna-sdk_alma_rel_v.5.32.0.zip: docs_sdk_archive_luna-sdk_alma_rel_v.5.32.0/luna-sdk_alma_rel_v.5.32.0/doc/fsdk/html/search/enumvalues_8.js <==
var searchData=
[
  ['ic_5fbest_5fcompression',['IC_BEST_COMPRESSION',['../structfsdk_1_1_image.html#acb272c751b60925b57a543cf19f31a5daccd72f086a3257b06c12b790a683f2d6',1,'fsdk::Image']]],
  ['ic_5fhard_5fcompression',['IC_HARD_COMPRESSION',['../structfsdk_1_1_image.html#acb272c751b60925b57a543cf19f31a5da60cdeb7647e393444a05d358810293f5',1,'fsdk::Image']]],
  ['ic_5fmedium_5fcompression',['IC_MEDIUM_COMPRESSION',['../structfsdk_1_1_image.html#acb272c751b60925b57a543cf19f31a5daf526f9c09cd1a065f528dc6518895615',1,'fsdk::Image']]],
  ['ic_5fno_5fcompression',['IC_NO_COMPRESSION',['../structfsdk_1_1_image.html#acb272c751b60925b57a543cf19f31a5dab75738e569f17ad386d0ff4cb90eabb9',1,'fsdk::Image']]],
  ['ic_5fsmall_5fcompression',['IC_SMALL_COMPRESSION',['../structfsdk_1_1_image.html#acb272c751b60925b57a543cf19f31a5dae811dec1e75f575972a667e83a23bd34',1,'fsdk::Image']]],
  ['incompatible',['Incompatible',['../structfsdk_1_1_i_descriptor_batch.html#af8054a7215c500c856b6b10e41e4be93a2a208768bc7995cc26b7f3797d24b0b1',1,'fsdk::IDescriptorBatch']]],
  ['incompatibledescriptors',['IncompatibleDescriptors',['../namespacefsdk.html#a811cc08198c8cb908dc856217ef6c4f6a98530c9f4969e4a2e2d84a7776a2be2a',1,'fsdk']]],
  ['incompatiblemodelversions',['IncompatibleModelVersions',['../namespacefsdk.html#a811cc08198c8cb908dc856217ef6c4f6acd90a241053a97f8ff283746c8bed63f',1,'fsdk']]],
  ['infrared',['Infrared',['../structfsdk_1_1_image_color_estimation.html#a571307a256f649446ab9f437604fd48cade1c318db60bc972858577273c2d1ddd',1,'fsdk::ImageColorEstimation']]],
  ['inputarchive',['InputArchive',['../structfsdk_1_1_i_serializable_object.html#a2e8ee7bbbbc97731f3dddfcf9c5276f0af7d6ea2b343a99ac0a2cd306ed96b5c7',1,'fsdk::ISerializableObject']]],
  ['int1',['Int1',['../structfsdk_1_1_i_settings_provider_1_1_value.html#a593ad9694be5ec4dfe8982cef26fe947a95a8d18f7debfc437b1669849e7dd925',1,'fsdk::ISettingsProvider::Value']]],
  ['int2',['Int2',['../structfsdk_1_1_i_settings_provider_1_1_value.html#a593ad9694be5ec4dfe8982cef26fe947adf23e4f8136317e83ee4579ba2a5e066',1,'fsdk::ISettingsProvider::Value']]],
  ['int3',['Int3',['../structfsdk_1_1_i_settings_provider_1_1_value.html#a593ad9694be5ec4dfe8982cef26fe947ab6b18a107e12ec3a414343d93b4d69ec',1,'fsdk::ISettingsProvider::Value']]],
  ['int4',['Int4',['../structfsdk_1_1_i_settings_provider_1_1_value.html#a593ad9694be5ec4dfe8982cef26fe947ac4b020c2b070595a491d27e82c03ab5d',1,'fsdk::ISettingsProvider::Value']]],
  ['internal',['Internal',['../structfsdk_1_1_i_descriptor_batch.html#af8054a7215c500c856b6b10e41e4be93aafbf0897a5a83fdd873dfb032ec695d3',1,'fsdk::IDescriptorBatch::Internal()'],['../structfsdk_1_1_i_settings_provider.html#a645a0b8fb7db4e4d2ddc5bdb68a5cad5aafbf0897a5a83fdd873dfb032ec695d3',1,'fsdk::ISettingsProvider::Internal()'],['../namespacefsdk.html#a811cc08198c8cb908dc856217ef6c4f6aafbf0897a5a83fdd873dfb032ec695d3',1,'fsdk::Internal()'],['../namespacefsdk.html#ab7f8be96a87fd4e85bd762a7f8f8f8fbaafbf0897a5a83fdd873dfb032ec695d3',1,'fsdk::Internal()'],['../namespacefsdk.html#a4d0fbacdb0e56a6f79c2eb3e276c4e83aafbf0897a5a83fdd873dfb032ec695d3',1,'fsdk::Internal()']]],
  ['invalidarchive',['InvalidArchive',['../structfsdk_1_1_image.html#a7929a4eb6155bd9430dac56142672936a538273d971a3da3f944bfb95091df5d8',1,'fsdk::Image']]],
  ['invalidattribute',['InvalidAttribute',['../structfsdk_1_1_i_settings_provider.html#a645a0b8fb7db4e4d2ddc5bdb68a5cad5a49069827e26a70a158193ed0595b485b',1,'fsdk::ISettingsProvider']]],
  ['invalidbatch',['InvalidBatch',['../namespacefsdk.html#a811cc08198c8cb908dc856217ef6c4f6a16cd466ba03251484ec4e4b1dba364f5',1,'fsdk']]],
  ['invalidbitmap',['InvalidBitmap',['../structfsdk_1_1_image.html#a7929a4eb6155bd9430dac56142672936abcdbc5068527815bd978d3cbba5e7deb',1,'fsdk::Image']]],
  ['invalidbuffersize',['InvalidBufferSize',['../namespacefsdk.html#a811cc08198c8cb908dc856217ef6c4f6a32d8099d0ff5ab8d8893e6902eeb1ad0',1,'fsdk']]],
  ['invalidcdata',['InvalidCdata',['../structfsdk_1_1_i_settings_provider.html#a645a0b8fb7db4e4d2ddc5bdb68a5cad5a20c6429b7ff545070b48df0668d686fe',1,'fsdk::ISettingsProvider']]],
  ['invalidcomment',['InvalidComment',['../structfsdk_1_1_i_settings_provider.html#a645a0b8fb7db4e4d2ddc5bdb68a5cad5ac51b09d66c17f113d52d2822fb71a757',1,'fsdk::ISettingsProvider']]],
  ['invalidconfig',['InvalidConfig',['../namespacefsdk.html#a811cc08198c8cb908dc856217ef6c4f6a636bc5ca1e0ceb3e4c67067618d7ae09',1,'fsdk']]],
  ['invalidconversion',['InvalidConversion',['../structfsdk_1_1_image.html#a7929a4eb6155bd9430dac56142672936aaf9d45225e9d3edf59f2fd40d4b9f157',1,'fsdk::Image']]],
  ['invalidcudakernel',['InvalidCudaKernel',['../structfsdk_1_1_image.html#a7929a4eb6155bd9430dac56142672936afc9c6b34d28deffc4e146c11aae1c623',1,'fsdk::Image']]],
  ['invaliddataptr',['InvalidDataPtr',['../structfsdk_1_1_image.html#a7929a4eb6155bd9430dac56142672936a588c80ae8885b51a5f0700894da5affe',1,'fsdk::Image']]],
  ['invaliddatasize',['InvalidDataSize',['../structfsdk_1_1_image.html#a7929a4eb6155bd9430dac56142672936a0a86fcdcc2094e925e3166b9710f8d82',1,'fsdk::Image']]],
  ['invaliddescriptor',['InvalidDescriptor',['../namespacefsdk.html#a811cc08198c8cb908dc856217ef6c4f6a5b17c8e23099885736ba8f8d05c32f6c',1,'fsdk']]],
  ['invaliddescriptorbatch',['InvalidDescriptorBatch',['../namespacefsdk.html#a811cc08198c8cb908dc856217ef6c4f6a7b9735f9f1303453ad41cd38fc3b2b77',1,'fsdk']]],
  ['invaliddescriptorid',['InvalidDescriptorId',['../namespacefsdk.html#a811cc08198c8cb908dc856217ef6c4f6a1a86be0290d50e138737e4cc52665468',1,'fsdk']]],
  ['invaliddetection',['InvalidDetection',['../namespacefsdk.html#a811cc08198c8cb908dc856217ef6c4f6a8f36304eeb9e7bd7da166f71d3a5671f',1,'fsdk']]],
  ['invaliddevice',['InvalidDevice',['../structfsdk_1_1_image.html#a7929a4eb6155bd9430dac56142672936a3634e01cc1296daece9832c5396808c2',1,'fsdk::Image']]],
  ['invaliddoctype',['InvalidDocType',['../structfsdk_1_1_i_settings_provider.html#a645a0b8fb7db4e4d2ddc5bdb68a5cad5a93650de0861d0516977f25b86ee42e5a',1,'fsdk::ISettingsProvider']]],
  ['invalidendelement',['InvalidEndElement',['../structfsdk_1_1_i_settings_provider.html#a645a0b8fb7db4e4d2ddc5bdb68a5cad5a811a6b500aa2374e3a70057141dccbbf',1,'fsdk::ISettingsProvider']]],
  ['invalidformat',['InvalidFormat',['../structfsdk_1_1_image.html#a7929a4eb6155bd9430dac56142672936ade236a235b4e8ffc9141676624753b2d',1,'fsdk::Image']]],
  ['invalidheight',['InvalidHeight',['../structfsdk_1_1_image.html#a7929a4eb6155bd9430dac56142672936aaff424fc1ea568827830b838a80cd934',1,'fsdk::Image']]],
  ['invalidimage',['InvalidImage',['../structfsdk_1_1_image.html#a7929a4eb6155bd9430dac56142672936a107a93f5ad9b48f874341eaa0141e0f9',1,'fsdk::Image::InvalidImage()'],['../namespacefsdk.html#a811cc08198c8cb908dc856217ef6c4f6a107a93f5ad9b48f874341eaa0141e0f9',1,'fsdk::InvalidImage()']]],
  ['invalidimageformat',['InvalidImageFormat',['../namespacefsdk.html#a811cc08198c8cb908dc856217ef6c4f6a4bb4fd071cf54bae94ece53fa687b8bf',1,'fsdk']]],
  ['invalidimagesize',['InvalidImageSize',['../namespacefsdk.html#a811cc08198c8cb908dc856217ef6c4f6a5a606ed9e3b82871cb31eb26d467bebf',1,'fsdk']]],
  ['invalidinput',['InvalidInput',['../structfsdk_1_1_i_descriptor_batch.html#af8054a7215c500c856b6b10e41e4be93ad8f78ca9a692a9411afbc7584b69d043',1,'fsdk::IDescriptorBatch::InvalidInput()'],['../structfsdk_1_1_image.html#a7929a4eb6155bd9430dac56142672936ad8f78ca9a692a9411afbc7584b69d043',1,'fsdk::Image::InvalidInput()'],['../namespacefsdk.html#a811cc08198c8cb908dc856217ef6c4f6ad8f78ca9a692a9411afbc7584b69d043',1,'fsdk::InvalidInput()'],['../namespacefsdk.html#ab7f8be96a87fd4e85bd762a7f8f8f8fbad8f78ca9a692a9411afbc7584b69d043',1,'fsdk::InvalidInput()']]],
  ['invalidlandmarks5',['InvalidLandmarks5',['../namespacefsdk.html#a811cc08198c8cb908dc856217ef6c4f6ab5c07ccab2c5b9c7577b777263e692aa',1,'fsdk']]],
  ['invalidlandmarks68',['InvalidLandmarks68',['../namespacefsdk.html#a811cc08198c8cb908dc856217ef6c4f6a5e323dba014fd8072bb4a29f3e39db8d',1,'fsdk']]],
  ['invalidmemory',['InvalidMemory',['../structfsdk_1_1_image.html#a7929a4eb6155bd9430dac56142672936a83fe3c82514cc399b416bbb9d25ac9a9',1,'fsdk::Image']]],
  ['invalidpath',['InvalidPath',['../structfsdk_1_1_image.html#a7929a4eb6155bd9430dac56142672936a5d0744802b24f44a161d350c25d76c7b',1,'fsdk::Image::InvalidPath()'],['../namespacefsdk.html#a811cc08198c8cb908dc856217ef6c4f6a5d0744802b24f44a161d350c25d76c7b',1,'fsdk::InvalidPath()']]],
  ['invalidpcdata',['InvalidPcdata',['../structfsdk_1_1_i_settings_provider.html#a645a0b8fb7db4e4d2ddc5bdb68a5cad5a65d83fd76501c29718cc8fde8b8f33db',1,'fsdk::ISettingsProvider']]],
  ['invalidpi',['InvalidPi',['../structfsdk_1_1_i_settings_provider.html#a645a0b8fb7db4e4d2ddc5bdb68a5cad5a96fe5a2a900fba7e5dd6fe5519f09e90',1,'fsdk::ISettingsProvider']]],
  ['invalidrect',['InvalidRect',['../namespacefsdk.html#a811cc08198c8cb908dc856217ef6c4f6a48a3a3a046f78d13629f687cc97461a0',1,'fsdk']]],
  ['invalidresidence',['InvalidResidence',['../structfsdk_1_1_image.html#a7929a4eb6155bd9430dac56142672936a2a7695a194a2f785215c4ed058e2bf7b',1,'fsdk::Image']]],
  ['invalidserializedobject',['InvalidSerializedObject',['../namespacefsdk.html#a811cc08198c8cb908dc856217ef6c4f6af3c0d24a751f6da0fe4f81bb2e10bb19',1,'fsdk']]],
  ['invalidsettings',['InvalidSettings',['../structfsdk_1_1_i_settings_provider.html#a645a0b8fb7db4e4d2ddc5bdb68a5cad5a37a5f254c366f6c4dcba8bfd75f1070e',1,'fsdk::ISettingsProvider']]],
  ['invalidsettingsprovider',['InvalidSettingsProvider',['../namespacefsdk.html#a811cc08198c8cb908dc856217ef6c4f6ab1af2f31ddaa685b9fabe328f28f3a6f',1,'fsdk']]],
  ['invalidspansize',['InvalidSpanSize',['../namespacefsdk.html#a811cc08198c8cb908dc856217ef6c4f6a9a93b3012aa094825f11f65e07763bb3',1,'fsdk']]],
  ['invalidstartelement',['InvalidStartElement',['../structfsdk_1_1_i_settings_provider.html#a645a0b8fb7db4e4d2ddc5bdb68a5cad5a17b7fccdd65da9c5a54552c3685041a4',1,'fsdk::ISettingsProvider']]],
  ['invalidtag',['InvalidTag',['../structfsdk_1_1_i_settings_provider.html#a645a0b8fb7db4e4d2ddc5bdb68a5cad5af155a86534ba8c83bd9ced7c8f510b4c',1,'fsdk::ISettingsProvider']]],
  ['invalidtransformation',['InvalidTransformation',['../namespacefsdk.html#a811cc08198c8cb908dc856217ef6c4f6a21481cb38ecea41b765ab2d86b594053',1,'fsdk']]],
  ['invalidtype',['InvalidType',['../structfsdk_1_1_image.html#a7929a4eb6155bd9430dac56142672936ac85f85f7c13ed006eed130ec183aa810',1,'fsdk::Image']]],
  ['invalidwidth',['InvalidWidth',['../structfsdk_1_1_image.html#a7929a4eb6155bd9430dac56142672936a6518a24cb2d8166f5c57016e65e3f419',1,'fsdk::Image']]],
  ['ioerror',['IoError',['../structfsdk_1_1_i_descriptor_batch.html#af8054a7215c500c856b6b10e41e4be93af05cfcbf5123775f7c73e520a8d861e1',1,'fsdk::IDescriptorBatch::IoError()'],['../structfsdk_1_1_i_settings_provider.html#a645a0b8fb7db4e4d2ddc5bdb68a5cad5a5206bd7472156351d2d9a99633ac9580',1,'fsdk::ISettingsProvider::IOError()']]],
  ['ir_5fx8x8x8',['IR_X8X8X8',['../structfsdk_1_1_format.html#a9074e215a3c98d8e5b125bbec8d19af1af4ca5a5a1ea5b7005c89a9cd0911d0b4',1,'fsdk::Format']]],
  ['iso',['ISO',['../structfsdk_1_1_head_pose_estimation.html#aa2121a6759ada82ee49750f4922fd9a7a4db45576db7f96e820b1388d1c522aff',1,'fsdk::HeadPoseEstimation']]]
];
